/* ISC license. */

/* Generated by: ./configure --prefix=/usr --sysconfdir=/etc --libexecdir=/usr/lib --disable-allstatic --disable-static --enable-pkgconfig --enable-shared --with-pkgconfig */

#ifndef MDEVD_CONFIG_H
#define MDEVD_CONFIG_H

#define MDEVD_VERSION "0.1.8.2"
#define MDEVD_BINPREFIX ""
#define MDEVD_EXTBINPREFIX ""
#define MDEVD_EXTLIBEXECPREFIX "/usr/lib/"
#define MDEVD_LIBEXECPREFIX "/usr/lib/"
#define MDEVD_SYSCONFPREFIX "/etc/"

#endif
